#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deferred-folds
version:              0.9.17
visibility:           public
id:                   deferred-folds-0.9.17-9Mw6lZK6g92BVtWndBo0PG
key:                  deferred-folds-0.9.17-9Mw6lZK6g92BVtWndBo0PG
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
stability:            Experimental
homepage:             https://github.com/metrix-ai/deferred-folds
synopsis:             Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.

category:             Folding
abi:                  d04279fcdb34d899573a0361b742a7d1
exposed:              True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr

hidden-modules:
    DeferredFolds.Types DeferredFolds.UnfoldrM
    DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
    DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
    DeferredFolds.Prelude DeferredFolds.Util.TextArray

import-dirs:          /usr/lib/ghc-8.10.5/site-local/deferred-folds-0.9.17
library-dirs:         /usr/lib/ghc-8.10.5/site-local/deferred-folds-0.9.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/deferred-folds-0.9.17
hs-libraries:         HSdeferred-folds-0.9.17-9Mw6lZK6g92BVtWndBo0PG
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1
    foldl-1.4.11-6zNe6dhXtnvBajDVx6aV9t
    hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo
    primitive-0.7.1.0-H44eQ1j8hQJ3Kj2SFx0Ivh text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock

haddock-html:         /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

